@@ -2,9 +2,9 @@ import enum
 
 
 class State(enum.Enum):
-    Started = 1
-    Finished = 2
-    Failed = 3
+    Idle = 1
+    Running = 2
+    Error = 3
 
 
 class Message:
